<?php
/**
 * Geral\Logic\GrupoServicos
 * @category Php
 * @package  Geral\Logic\GrupoServicos
 * @author   matthaeuscarvalho <matthaeus.carvalho@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Geral\Logic\GrupoServicos;

use Geral\Entities\Grupserv;
use Geral\Entities\Turnoserv;
use Geral\Entities\Servico;
use Geral\Util\DateUtil;
use Planejamento\Entities\Confcard;
use Setforms2\Shared\Registry;
use \Setforms2\Runtime\Framework;

/**
 * Class GrupoServicos
 * @category Php
 * @package  Geral\Logic\GrupoServicos
 * @author   matthaeuscarvalho <matthaeus.carvalho@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class GrupoServicos
{
    /**
     * Retorna o próximo código do grupo de serviços
     *
     * @param String $nrorg Organização
     *
     * @return mixed
     */
    public static function retornaProximoCdGrupServ($nrorg)
    {
        /** @var $repository \Geral\Repositories\Grupserv */
        $repository = Grupserv::getRepository();
        return $repository->retornaProximoCdGrupoServ($nrorg);
    }

    /**
     * Retorna o próximo código do turno
     *
     * @param String $nrorg   Organização
     * @param String $filial  Unidade
     * @param String $servico Serviço
     *
     * @return int
     */

    public static function retornaProximoCdTurno($nrorg, $filial, $servico)
    {
        /** @var $turno Turnoserv */
        $turno = Turnoserv::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ?',
            array($nrorg, $filial, $servico),
            'CDTURNO DESC'
        );

        if ($turno instanceof Turnoserv) {
            $maiorCd = $turno->getCdturno();
        } else {
            $maiorCd = 0;
        }
        return ++$maiorCd;
    }
    /**
    * Retorna o número de linhas registrados 
    * @param  String $cdfilial , $cdservfilial, $cdturno
    */
    public static function contaRegistros($cdfilial, $cdservfili)
    {
        try{
            $codigoData = Turnoserv::getObjectsByWhere('CDFILIAL = ? AND CDSERVFILI = ?', 
            array($cdfilial, $cdservfili));

            if ($codigoData) {
                return count($codigoData);        
            } else {
                return 0;
            }

    } catch(\Exception $e){
        throw $e;
        
    }
    }
    /**
    * Insere corretamente novos turnos
    */
    public static function insereTurno($cdfilial,$cdservfili,$cdturno,$nmTurno,$nrorg,$qtcomesttseg,$qtcomesttter,
                                       $qtcomesttqua,$qtcomesttqui,$qtcomesttsex,$qtcomesttsab,$qtcomesttdom,$qtcomesttfer,$dtUltatu)
{
            $con = Registry::getEntityManager();
            $con->beginTransaction();
            try{
                /**
                 * @var \Geral\Entities\Turnoserv $turno */
                $turnoserv = new \Geral\Entities\Turnoserv();
                $turnoserv->setDtinclusao(DateUtil::getDataAtual());
                $turnoserv->setCdfilial($cdfilial);
                $turnoserv->setCdservfili($cdservfili);
                $turnoserv->setCdturno($cdturno);
                $turnoserv->setNmturno($nmTurno);
                $turnoserv->setNrorg($nrorg);
                $turnoserv->setQtcomesttseg($qtcomesttseg);
                $turnoserv->setQtcomesttter($qtcomesttter);
                $turnoserv->setQtcomesttqua($qtcomesttqua);
                $turnoserv->setQtcomesttqui($qtcomesttqui);
                $turnoserv->setQtcomesttsex($qtcomesttsex);
                $turnoserv->setQtcomesttsab($qtcomesttsab);
                $turnoserv->setQtcomesttdom($qtcomesttdom);
                $turnoserv->setQtcomesttfer($qtcomesttfer);
                $turnoserv->setDtultatu($dtUltatu);

                $turnoserv->persist();
                $con->flush();
                $con->commit();
            } catch(\Exception $e){
                $con->rollback();
                Throw $e;
            }
}
    public static function atualizaTurno($cdfilial,$cdservfili,$cdturno,$nmTurno,$nrorg,$qtcomesttseg,$qtcomesttter,
                                         $qtcomesttqua,$qtcomesttqui,$qtcomesttsex,$qtcomesttsab,$qtcomesttdom,$qtcomesttfer,$dtUltatu){
        $con = Registry::getEntityManager();
        $con->beginTransaction();
        try{
            $inserido = false;
            /**
             * @var \Geral\Entities\Turnoserv $turno */
            $turno = TurnoServ::getObjectByWhere('NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ? AND CDTURNO = ?', array($nrorg,$cdfilial,$cdservfili,$cdturno));
            if(!($turno)) {
                /** @var \Geral\Entities\Turnoserv $turno */
                $turno = new \Geral\Entities\Turnoserv();
                $turno->setDtinclusao(DateUtil::getDataAtual());
                $inserido = true;
            }
            if($turno){
                $turno->setCdfilial($cdfilial);
                $turno->setCdservfili($cdservfili);
                $turno->setCdturno($cdturno);
                $turno->setNmturno($nmTurno);
                $turno->setNrorg($nrorg);
                $turno->setQtcomesttseg($qtcomesttseg);
                $turno->setQtcomesttter($qtcomesttter);
                $turno->setQtcomesttqua($qtcomesttqua);
                $turno->setQtcomesttqui($qtcomesttqui);
                $turno->setQtcomesttsex($qtcomesttsex);
                $turno->setQtcomesttsab($qtcomesttsab);
                $turno->setQtcomesttdom($qtcomesttdom);
                $turno->setQtcomesttfer($qtcomesttfer);
                $turno->setDtultatu($dtUltatu);
                $turno->persist();
                $con->flush();
                $con->commit();
                if ($inserido){
                    tk_message(tk_get_message_by_name('msg_ger04100_inserido'),'Success');
                }
                else {
                    tk_message(tk_get_message_by_name('msg_ger04100_atualizado'),'Success');
                }
                tk_reload_data_with_filter();
            }
        } catch(\Exception $e){
            $con->rollback();
            Throw $e;
        }
    }
    /**
     * Atualiza as informações alteradas no grid no Banco de dados
     */
    public static function atualizaTipoPrato($nrorg, $filial, $cdTipoPrato, $cdservfili, $nrseqcnfcard) {
        $nrorg = Ambiente::getNrorg();
        $linhas = Framework::getInstance()->getDataset();
        foreach ($linhas as $linha) {
            $cdTipoPrato = $linha['CDTIPOPRAT'];
            $filial = $linha['CDFILIAL'];
            $cdservfili = $linha['CDSERVFILI'];
            $nrseqcnfcard = $linha['NRSEQCNFCARD'];
            Confcard::atualizaConfCard($nrorg, $filial, $cdTipoPrato, $cdservfili, $nrseqcnfcard);
        }
    }

    /**
     * Atualiza os comensais
     *
     * @param String $filial      Unidade
     * @param String $nrorg       Organização
     * @param String $dia         Dia
     * @param String $cliente     Cliente
     * @param String $funcionario Funcionário
     * @param String $doacao      Doação
     * @param String $servico     Serviço
     * @param String $operador    Operador
     *
     * @return null
     * @throws \Exception
     */
    public static function atualizaComensais(
        $filial, $nrorg, $dia, $cliente, $funcionario, $doacao, $servico, $operador
    ) {
        $con = Registry::getEntityManager();
        $con->beginTransaction();

        try {
            /** @var $servico Servico */
            $servico = Servico::getObject(array('nrorg' => $nrorg, 'cdfilial' => $filial, 'cdservfili' => $servico));
            $servico->atualizaComensaisEstimados($nrorg, $dia, $cliente, $funcionario, $doacao, $operador);
            $con->flush();
            $con->commit();
            //

        } catch (\Exception $e) {
            $con->rollback();
            Throw $e;
        }
    }   
    /**
    * Retorna os Pontos de entrega da Filial correspondente
    */
     public static function getPontosFilial($cdfilial,$nmdestifilial){
        $pontos = destfili::getObjectsByWhere('CDFILIAL = ? AND NMDESTFILI = ?', array($cdfilial,$nmdestifilial)
            );
        return $pontos;
    }
 
}
